nxp-pac

Crates

git

Versions

mcxa577

Flavors

P4irulestat

Struct P4irulestat 

#[repr(transparent)]
pub struct P4irulestat(pub u32);
Set Interrupt Rules and User Status

Tuple Fields

0: u32

Implementations

Source

impl P4irulestat

pub const fn ustat(&self) -> u8

User-Defined Status Bits

pub const fn set_ustat(&mut self, val: u8)

User-Defined Status Bits

pub const fn interr(&self) -> bool

Interrupt If Error Detected

pub const fn set_interr(&mut self, val: bool)

Interrupt If Error Detected

pub const fn intrd(&self) -> bool

Interrupt If Read or First Read or Bus Master Started

pub const fn set_intrd(&mut self, val: bool)

Interrupt If Read or First Read or Bus Master Started

pub const fn intwr(&self) -> bool

Interrupt If Write or First Write or Bus Master Finished

pub const fn set_intwr(&mut self, val: bool)

Interrupt If Write or First Write or Bus Master Finished

pub const fn intspc(&self) -> u8

Select Interrupts for PnSTAT[INTSPC0] through PnSTAT[INSTSPC3]

pub const fn set_intspc(&mut self, val: u8)

Select Interrupts for PnSTAT[INTSPC0] through PnSTAT[INSTSPC3]

pub const fn sstcl(&self) -> u8

Status Set and Clear

pub const fn set_sstcl(&mut self, val: u8)

Status Set and Clear

pub const fn srst(&self) -> bool

Reset PnSTAT[RDSTAT] and PnSTAT[WRSTAT]

pub const fn set_srst(&mut self, val: bool)

Reset PnSTAT[RDSTAT] and PnSTAT[WRSTAT]

pub const fn flash_completion_type(&self) -> P4irulestatFlashCompletionType

Flash Completion Type

pub const fn set_flash_completion_type( &mut self, val: P4irulestatFlashCompletionType, )

Flash Completion Type

pub const fn cpu_tag(&self) -> u8

CPU Tag

pub const fn set_cpu_tag(&mut self, val: u8)

CPU Tag